# -*- coding: utf-8 -*-
from setuphelpers import *

r"""
Usable WAPT package functions: install(), uninstall(), session_setup(), audit(), update_package()

https://docs.microsoft.com/previous-versions/windows/it-pro/windows-server-2012-r2-and-2012/jj134237(v=ws.11)


PrintBrm -B|R|Q [-S <server>] -F <file> [-D <directory>] [-O FORCE] [-P ALL|ORIG] [-NOBIN] [-LPR2TCP] [-C <config file>] [-NOACL] [-?]
-B               Backup the server to the specified file
-R               Restore the configuration in the file to the server
-Q               Query the server or the backup file
-S <server name> Target server
-F <file name>   Target backup File
-D <directory>   Unpack the backup file to (with -R) or repack a backup file from (with -B) the given directory
-O FORCE         Force overwriting of existing objects
-P ALL|ORIG      Publish all printers in directory, or publish printers that were published originally
-NOBIN           Omit the binaries from the backup
-LPR2TCP         Convert LPR ports to Standard TCP/IP ports on restore
-C <file name>   Use the specified configuration file for BRM
-NOACL           Remove ACLs from print queues on restore
-?               Display this help

https://docs.microsoft.com/powershell/module/printmanagement/get-printer

Name                           ComputerName    Type         DriverName                PortName        Shared   Published  DeviceType
----                           ------------    ----         ----------                --------        ------   ---------  ----------
Printer1                                       Local        HP Universal Printing PC… IP_192.168.0.1  False    False      Print
Microsoft Print to PDF                         Local        Microsoft Print To PDF    PORTPROMPT:     False    False      Print

To prepare this package, just run update-package, the package will suggest you a recommended process. You can run this update-package from the waptconsole if running as local administrator


"""
# Declaring global variables - Warnings: 1) WAPT context is only available in package functions; 2) Global variables are not persistent between calls
printbrm_path = makepath("%windir%", r"System32\spool\tools\PrintBrm.exe")
windows_temp_dir = makepath(systemdrive, "Windows", "Temp")
printers_export_file = "export.printerExport"
printers_export_path = makepath(windows_temp_dir, printers_export_file)
printers_backup_file = "backup.printerExport"
printers_backup_path = makepath(windows_temp_dir, printers_backup_file)
printers_manual_backup_file = "manual_backup.printerExport"
printers_manual_backup_path = makepath(windows_temp_dir, printers_manual_backup_file)
to_import_printers_list = ["Printer1"]  # To fill manually if you want the package to being able to uninstall imported printers
force_config = True  # Forces overwriting of existing objects.


def install():
    # Force config is requested
    if force_config:
        printbrm_option = "-O FORCE"
    else:
        printbrm_option = ""

    # Installing printers with drivers and configuration
    print(run(r'"%s" -r -f %s %s' % (printbrm_path, printers_export_file, printbrm_option)))


def uninstall():
    for printer_name in to_import_printers_list:
        remove_printer(printer_name)
